<?php
/**
 * Header template for the theme.
 *
 * Displays all of the <head> section and everything up until <div id="content">
 *
 * @package WordPress
 * @subpackage Brave New World
 * @since Brave New World 3.0
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta http-equiv="content-type" content="<?php bloginfo('html_type') ?>; charset=<?php bloginfo('charset') ?>" />
	<title><?php
	/*
	* Print the <title> tag based on what is being viewed.
	* We filter the output of wp_title() a bit -- see
	* twentyten_filter_wp_title() in functions.php.
	*/
	wp_title( '|', true, 'right' );
	
	?></title>
	<link rel="profile" href="http://gmpg.org/xfn/11" />
	<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
	<!--[if lt IE 9]>
		<script type="text/javascript" src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
	<![endif]-->
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
	<?php
	/* We add some JavaScript to pages with the comment form
	* to support sites with threaded comments (when in use).
	*/
	if ( is_singular() && get_option( 'thread_comments' ) )
	wp_enqueue_script( 'comment-reply' );
	
	/* Always have wp_head() just before the closing </head>
	* tag of your theme, or you will break many plugins, which
	* generally use this hook to add elements to <head> such
	* as styles, scripts, and meta tags.
	*/
	wp_head();
	?>
</head>

<body <?php body_class(); ?>>
	<div id="access" role="navigation">
		<?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff */ ?>
		<a href="#content" title="<?php esc_attr_e( 'Skip to content', 'twentyten' ); ?>"><?php _e( 'Skip to content', 'twentyten' ); ?></a>
	</div><!-- #access -->
	
	<header role="banner">
		<?php /*  We'll use an H1 for the home page and a div for all other pages, applying style via id="site-title" */ ?>
		<?php $heading_tag = ( is_home() || is_front_page() ) ? 'h1' : 'div'; ?>
		<<?php echo $heading_tag; ?> id="site-title">
		<span><a href="<?php echo home_url( '/' ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></span>
		</<?php echo $heading_tag; ?>>
		<p id="site-description"><?php bloginfo( 'description' ); ?></p>
		<?php
		// Check if this is a post or page, if it has a thumbnail, and if it's a big one
		if ( is_singular() &&
		has_post_thumbnail( $post->ID ) &&
		( /* $src, $width, $height */ $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'post-thumbnail' ) ) &&	$image[1] >= HEADER_IMAGE_WIDTH ) :
		// Houston, we have a new header image!
			echo get_the_post_thumbnail( $post->ID, 'post-thumbnail' );
		else : ?>
			<img src="<?php header_image(); ?>" width="<?php echo HEADER_IMAGE_WIDTH; ?>" height="<?php echo HEADER_IMAGE_HEIGHT; ?>" alt="" />
		<?php endif; ?>
	</header>
	<nav role="navigation">
		<?php /* Our navigation menu.  If one isn't filled out, wp_nav_menu falls back to wp_page_menu.  The menu assiged to the primary position is the one used.  If none is assigned, the menu with the lowest ID is used.  */ ?>
		<?php wp_nav_menu( array( 'container_class' => 'menu-header', 'theme_location' => 'primary' ) ); ?>
	</nav>
	<div id="content">