<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content.  See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * This can be overridden in child themes with loop.php or
 * loop-template.php, where 'template' is the loop context
 * requested by a template. For example, loop-index.php would
 * be used if it exists and we ask for the loop with:
 * <code>get_template_part( 'loop', 'index' );</code>
 *
 * Classes added to support hAtom and hCard Microformats
 *
 * @package WordPress
 * @subpackage Brave New World
 * @since Brave New World 3.0
 */
?>
<div class="hfeed" role="main">
<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
	<nav>
		<?php next_posts_link( __( '&larr; Older posts', 'twentyten' ) ); ?>
		<?php previous_posts_link( __( 'Newer posts &rarr;', 'twentyten' ) ); ?>
	</nav>
<?php endif; ?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<h1><?php _e( 'Not Found', 'twentyten' ); ?></h1>
	<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'twentyten' ); ?></p>
	<?php get_search_form(); ?>
<?php endif; ?>

<?php
/* Start the Loop.
 *
 * In Twenty Ten we use the same loop in multiple contexts.
 * It is broken into three main parts: when we're displaying
 * posts that are in the gallery category, when we're displaying
 * posts in the asides category, and finally all other posts.
 *
 * Additionally, we sometimes check for whether we are on an
 * archive page, a search page, etc., allowing for small differences
 * in the loop on each template without actually duplicating
 * the rest of the loop that is shared.
 *
 * Without further ado, the loop:
 */ ?>
	 
<?php while ( have_posts() ) : the_post(); ?>
	<?php /* How to display posts in the Gallery category. */ ?>
	<?php if ( in_category( _x('gallery', 'gallery category slug', 'twentyten') ) ) : ?>
	<article class="hentry" id="post-<?php the_ID(); ?>">
		<header>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
			<span class="by">by</span><address class="vcard author"><span class="fn url"><?php the_author() ?></span></address>
			<time datetime="<?php the_date_xml() ?>" class="published date"><span class="day"><?php the_time('d') ?></span><span class="month"><?php the_time('M') ?></span><span class="year"><?php the_time('Y') ?></span></time>
		</header>

		<?php if ( post_password_required() ) : ?>
			<div class="entry-content"><?php the_content(); ?></div>
			
		<?php else : ?>
			<div class="entry-content">
			<?php
				$images = get_children( array( 'post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image', 'orderby' => 'menu_order', 'order' => 'ASC', 'numberposts' => 999 ) );
				$total_images = count( $images );
				$image = array_shift( $images );
				$image_img_tag = wp_get_attachment_image( $image->ID, 'thumbnail' );
			?>
			<a href="<?php the_permalink(); ?>"><?php echo $image_img_tag; ?></a>
			<p><?php printf( __( 'This gallery contains <a %1$s>%2$s photos</a>.', 'twentyten' ), 'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink to %s', 'twentyten' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"',	$total_images); ?></p>
			</div>
			<div class="entry-summary"><?php the_excerpt(); ?></div>
		<?php endif; ?>

		<footer>
			<a href="<?php echo get_term_link( _x('gallery', 'gallery category slug', 'twentyten'), 'category' ); ?>" title="<?php esc_attr_e( 'View posts in the Gallery category', 'twentyten' ); ?>"><?php _e( 'More Galleries', 'twentyten' ); ?></a>	| <?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?> <?php edit_post_link( __( 'Edit', 'twentyten' ), '|', '' ); ?>
		</footer>
	</article><!-- #post-## -->
	
	<?php /* How to display posts in the asides category */ ?>
	<?php elseif ( in_category( _x('asides', 'asides category slug', 'twentyten') ) ) : ?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<?php if ( is_archive() || is_search() ) : // Display excerpts for archives and search. ?>
			<div class="entry-summary"><?php the_excerpt(); ?></div>
		<?php else : ?>
			<div class="entry-content"><?php the_content( __( 'Continue reading &rarr;', 'twentyten' ) ); ?></div>
		<?php endif; ?>
		<footer>
		<?php twentyten_posted_on(); ?>	| <?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?> <?php edit_post_link( __( 'Edit', 'twentyten' ), '| ', '' ); ?>
		</footer>
	</article>

	<?php /* How to display all other posts. */ ?>
	<?php else : ?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<header>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
			<span class="by">by</span><address class="vcard author"><span class="fn url"><?php the_author() ?></span></address>
			<time datetime="<?php the_date_xml() ?>" class="published date"><span class="day"><?php the_time('d') ?></span><span class="month"><?php the_time('M') ?></span><span class="year"><?php the_time('Y') ?></span></time>
		</header>
		<?php if ( is_home() || is_archive() || is_search() ) : // Only display excerpts for the home page, archives and search. ?>
			<div class="entry-summary"><?php the_excerpt(); ?></div>
		<?php else : ?>
			<div class="entry-content"><?php the_content( __( 'Continue reading &rarr;', 'twentyten' ) ); ?></div>
			<nav><?php wp_link_pages( array( 'before' => '' . __( 'Pages:', 'twentyten' ), 'after' => '' ) ); ?></nav>
		<?php endif; ?>
		<footer>
			<?php if ( count( get_the_category() ) ) : ?>
				<?php printf( __( 'Posted in %2$s', 'twentyten' ), 'entry-utility-prep entry-utility-prep-cat-links', get_the_category_list( ', ' ) ); ?> |	
			<?php endif; ?>
			<?php $tags_list = get_the_tag_list( '', ', ' ); if ( $tags_list ):	?>
				<?php printf( __( 'Tagged %2$s', 'twentyten' ), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list ); ?>	|
			<?php endif; ?>
			<?php comments_popup_link( __( 'Leave a comment', 'twentyten' ), __( '1 Comment', 'twentyten' ), __( '% Comments', 'twentyten' ) ); ?>
			<?php edit_post_link( __( 'Edit', 'twentyten' ), '| ', '' ); ?>
		</footer>
		<section>
			<?php comments_template( '', true ); ?>
		</section>
	</article>
	<?php endif; // This was the if statement that broke the loop into three parts based on categories. ?>
<?php endwhile; // End the loop. Whew. ?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if (  $wp_query->max_num_pages > 1 ) : ?>
	<nav>
		<?php next_posts_link( __( '&larr; Older posts', 'twentyten' ) ); ?>
		<?php previous_posts_link( __( 'Newer posts &rarr;', 'twentyten' ) ); ?>
	</nav>
<?php endif; ?>
</div><!-- end hfeed -->